lnorm_sdlog: Calculates the standard deviation parameter for a log normal...

Description Usage Arguments Value Examples

View source: R/distributions.R

Description

Calculates the standard deviation parameter for a log normal distribution given the gini coefficient.

Usage

1

Arguments

gini

A number representing the gini coefficient

Value

the standard deviation

Examples

1
2

ianksalter/bistr documentation built on May 4, 2020, 12:16 a.m.